Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(907)

Unified Diff: mojo/application/public/cpp/application_impl.h

Issue 1257703003: Revert of ApplicationImpl cleanup, part 1: (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: mojo/application/public/cpp/application_impl.h
diff --git a/mojo/application/public/cpp/application_impl.h b/mojo/application/public/cpp/application_impl.h
index 5d2eb45f64b5ae66a46a7c4b591db70b39835ff6..9c040131f4a1a2c60eb26ccab85120f773a2ff35 100644
--- a/mojo/application/public/cpp/application_impl.h
+++ b/mojo/application/public/cpp/application_impl.h
@@ -19,7 +19,6 @@
namespace mojo {
-// TODO(beng): This comment is hilariously out of date.
// Utility class for communicating with the Shell, and providing Services
// to clients.
//
@@ -60,8 +59,8 @@
ApplicationImpl(ApplicationDelegate* delegate,
InterfaceRequest<Application> request);
// Constructs an ApplicationImpl with a custom termination closure. This
// closure is invoked on Quit() instead of the default behavior of quitting
// the current base::MessageLoop.
ApplicationImpl(ApplicationDelegate* delegate,
InterfaceRequest<Application> request,
const Closure& termination_closure);
@@ -114,9 +113,12 @@
void UnbindConnections(InterfaceRequest<Application>* application_request,
ShellPtr* shell);
- // Initiate shutdown of this application. This may involve a round trip to the
- // Shell to ensure there are no inbound service requests.
- void Quit();
+ // Quits the main run loop for this application. It first checks with the
+ // shell to ensure there are no outstanding service requests.
+ void Terminate();
+
+ // Quits without waiting to check with the shell.
+ void QuitNow();
private:
// Application implementation.
@@ -130,10 +132,6 @@
void OnConnectionError();
void ClearConnections();
-
- // Called from Quit() when there is no Shell connection, or asynchronously
- // from Quit() once the Shell has OK'ed shutdown.
- void QuitNow();
typedef std::vector<internal::ServiceRegistry*> ServiceRegistryList;
« no previous file with comments | « mojo/application/public/cpp/app_lifetime_helper.h ('k') | mojo/application/public/cpp/lib/app_lifetime_helper.cc » ('j') | no next file with comments »
@@ -60,8 +59,8 @@
InterfaceRequest<Application> request);
// Constructs an ApplicationImpl with a custom termination closure. This
- // closure is invoked on Quit() instead of the default behavior of quitting
- // the current base::MessageLoop.
+ // closure is invoked on Terminate() instead of the default behavior of
+ // quitting the current MessageLoop.
ApplicationImpl(ApplicationDelegate* delegate,
InterfaceRequest<Application> request,

Powered by Google App Engine
This is Rietveld 408576698